@@ -48,12 +48,6 @@ sFile* sFile_new(char* name, struct stat* stat_)
     return self;
 }
 
-void sFile_delete(sFile* self)
-{
-    string_delete(self->mName);
-    FREE(self);
-}
-
 static BOOL sort_name(void* left, void* right)
 {
     sFile* l = (sFile*) left;
@@ -354,9 +348,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
     else if(same_point == strlen(text)) {
         char tmp[PATH_MAX];
         xstrncpy(tmp, file, PATH_MAX);
-        char* ret = strdup(tmp);
-
-        return ret;
+        return strdup(tmp);
     }
     else {
         p = migemo_query(gMigemo, text+same_point);
@@ -398,8 +390,6 @@ char* readline_file_completion_migemo_match(char* text, char* file)
         r = onig_new(&reg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
     }
 
-    FREE(p2);
-
     migemo_release(gMigemo, (unsigned char*) p);
 
     if(r != ONIG_NORMAL) {
@@ -425,9 +415,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
     if(r2 == 0) {
         char tmp[PATH_MAX];
         xstrncpy(tmp, file, PATH_MAX);
-        char* ret = strdup(tmp);
-
-        return ret;
+        return strdup(tmp);
     }
 
     return NULL;
@@ -464,7 +452,6 @@ char* readline_file_completion_migemo(const char* text, int rstat)
         char* tmp = MALLOC(string_length(gEditingDir) + 1);
         parentname2(tmp, string_length(gEditingDir) + 1, string_c_str(gEditingDir));
         string_put(gEditingDir, tmp);
-        FREE(tmp);
 
         /// チルダから始まっている場合 ///
         if(string_c_str(gEditingDir)[0] == '~') {
@@ -507,10 +494,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
 
             string_push_back(gEditingDir2, p);
 
-            string_delete(user);
-
             string_put(gEditingDir, string_c_str(gEditingDir2));
-            string_delete(gEditingDir2);
         }
 
         /// 補完候補を初期化 ///
@@ -518,10 +502,6 @@ char* readline_file_completion_migemo(const char* text, int rstat)
             files = VECTOR_NEW(50);
         }
         else {
-            int i;
-            for(i=0; i<vector_size(files); i++) {
-                string_delete(vector_item(files, i));
-            }
             vector_clear(files);
         }
 
@@ -557,8 +537,6 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                             }
                         }
                         xstrncpy(buf, des, PATH_MAX);
-
-                        FREE(des);
                         }
 #else
                         xstrncpy(buf, entry->d_name, PATH_MAX);
@@ -608,7 +586,6 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                             }
                         }
                         xstrncpy(buf, des, PATH_MAX);
-                        FREE(des);
                         }
 #else
                         xstrncpy(buf, entry->d_name, PATH_MAX);
@@ -653,10 +630,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                 rl_completion_append_character= ' ';
             }
 
-            if(ret) {
-                FREE(text2);
-                return ret;
-            }
+            return ret;
         }
 
         /// アスキー文字同士の補完 ///
@@ -668,7 +642,6 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                 string_obj* tmp2 = STRING_NEW("");
                 saphire_get_quoted_fname(path, tmp2);
                 char* ret = strdup(string_c_str(tmp2));
-                string_delete(tmp2);
 
                 xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
                 xstrncat(path, file, PATH_MAX);
@@ -685,10 +658,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                     rl_completion_append_character= ' ';
                 }
 
-                if(ret) { 
-                    FREE(text2);
-                    return ret; 
-                }
+                return ret; 
             }
         }
         /// migemo 補完 ///
@@ -711,29 +681,22 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                     rl_completion_append_character= ' ';
                 }
 
-                FREE(text2);
-
                 string_obj* tmp = STRING_NEW("");
                 saphire_get_quoted_fname(ret, tmp);
-                FREE(ret);
+                free(ret);
 
-                ret = STRDUP(string_c_str(tmp));
-                string_delete(tmp);
-
-                return ret;
+                return strdup(string_c_str(tmp));
             }
         }
     }
 
     if(index == 0 && vector_size(files) == 0) {
         index ++;
-        FREE(text2);
         rl_completion_append_character= 0;
         return strdup("");
     }
 
 
-    FREE(text2);
     return NULL;
 }
 #endif
@@ -759,55 +722,6 @@ char* readline_program_completion(const char* text, int stat)
     return NULL;
 }
 
-char* readline_env_completion(const char* text, int stat)
-{
-    static int index, wordlen;
-
-    if(stat == 0) {
-        wordlen = strlen(text);
-        index = 0;
-    
-        saphire_make_var_completion_list();
-    }
-    while(1) {
-        if(index < vector_size(gSaphireVarCompletions)) {
-            char* env = string_c_str(vector_item(gSaphireVarCompletions, index));
-            int env2_size = strlen(env) + 10;
-            char* env2 = malloc(env2_size);
-
-            if(*text == '$' && *(text+1) != '$') {
-                xstrncpy(env2, "$", env2_size);
-                xstrncat(env2, env, env2_size);
-            }
-            else if(*text == '$' && *(text+1) == '$') {
-                xstrncpy(env2, "$$", env2_size);
-                xstrncat(env2, env, env2_size);
-            }
-            else if(*text == '@' && *(text+1) != '@') {
-                xstrncpy(env2, "@", env2_size);
-                xstrncat(env2, env, env2_size);
-            }
-            else if(*text == '@' && *(text+1) == '@') {
-                xstrncpy(env2, "@@", env2_size);
-                xstrncat(env2, env, env2_size);
-            }
-
-            index++;
-
-            if(strncmp(text, env2, wordlen) == 0) {
-                return env2;
-            }
-
-            free(env2);
-        }
-        else {
-            break;
-        }
-    }
-
-    return NULL;
-}
-
 char* readline_file_completion(const char* text, int rstat)
 {
     /// クォートを除外 ///
@@ -838,7 +752,6 @@ char* readline_file_completion(const char* text, int rstat)
         char* tmp = MALLOC(string_length(gEditingDir) + 1);
         parentname2(tmp, string_length(gEditingDir) + 1, string_c_str(gEditingDir));
         string_put(gEditingDir, tmp);
-        FREE(tmp);
 
         /// チルダから始まっている場合 ///
         if(string_c_str(gEditingDir)[0] == '~') {
@@ -881,10 +794,7 @@ char* readline_file_completion(const char* text, int rstat)
 
             string_push_back(gEditingDir2, p);
 
-            string_delete(user);
-
             string_put(gEditingDir, string_c_str(gEditingDir2));
-            string_delete(gEditingDir2);
         }
 
         /// 補完候補を初期化 ///
@@ -892,10 +802,6 @@ char* readline_file_completion(const char* text, int rstat)
             files = VECTOR_NEW(50);
         }
         else {
-            int i;
-            for(i=0; i<vector_size(files); i++) {
-                string_delete(vector_item(files, i));
-            }
             vector_clear(files);
         }
 
@@ -931,7 +837,6 @@ char* readline_file_completion(const char* text, int rstat)
                             }
                         }
                         xstrncpy(buf, des, PATH_MAX);
-                        FREE(des);
                         }
 #else
                         xstrncpy(buf, entry->d_name, PATH_MAX);
@@ -980,7 +885,6 @@ char* readline_file_completion(const char* text, int rstat)
                             }
                         }
                         xstrncpy(buf, des, PATH_MAX);
-                        FREE(des);
                         }
 #else
                         xstrncpy(buf, entry->d_name, PATH_MAX);
@@ -1025,10 +929,7 @@ char* readline_file_completion(const char* text, int rstat)
                 rl_completion_append_character= ' ';
             }
 
-            if(ret) {
-                FREE(text2);
-                return ret;
-            }
+            return ret;
         }
 
         /// アスキー文字同士の補完 ///
@@ -1041,7 +942,6 @@ char* readline_file_completion(const char* text, int rstat)
                 string_obj* tmp2 = STRING_NEW("");
                 saphire_get_quoted_fname(path, tmp2);
                 char* ret = strdup(string_c_str(tmp2));
-                string_delete(tmp2);
 
                 xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
                 xstrncat(path, file, PATH_MAX);
@@ -1058,32 +958,23 @@ char* readline_file_completion(const char* text, int rstat)
                     rl_completion_append_character= ' ';
                 }
 
-                if(ret) { 
-                    FREE(text2);
-                    return ret; 
-                }
+                return ret; 
             }
         }
     }
 
     if(index == 0 && vector_size(files) == 0) {
         index ++;
-        FREE(text2);
         rl_completion_append_character= 0;
         return strdup("");
     }
 
-
-    FREE(text2);
     return NULL;
 }
 
 char** readline_on_complete(const char* text, int start, int end)
 {
-//printf("\n\ntext (%s) start %d end %d rl_line_buffer %s\n\n", text, start, end, rl_line_buffer);
-    
     BOOL program = TRUE;
-    BOOL env = FALSE;
     BOOL user = FALSE;
 
     char* p = rl_line_buffer;
@@ -1098,22 +989,18 @@ char** readline_on_complete(const char* text, int start, int end)
         // クォート
         if(*p == '\\' && *(p+1) == 't') {
             p+=2;
-            env = FALSE;
             user = FALSE;
         }
         else if(*p == '\\' && *(p+1) == 'n') {
             p+=2;
-            env = FALSE;
             user = FALSE;
         }
         else if(*p == '\\' && *(p+1) == 'r') {
             p+=2;
-            env = FALSE;
             user = FALSE;
         }
         else if(*p == '\\') {
             p+=2;
-            env = FALSE;
             user = FALSE;
         }
 
@@ -1121,14 +1008,12 @@ char** readline_on_complete(const char* text, int start, int end)
         else if(!dquote && *p == '\'') {
             p++;
             squote = !squote;
-            env = FALSE;
             user = FALSE;
         }
         // ダブルクォート
         else if(!squote && *p == '"') {
             p++;
             dquote = !dquote;
-            env = FALSE;
             user = FALSE;
         }
         // 環境変数 $$()
@@ -1140,7 +1025,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         // 環境変数 $()
@@ -1151,7 +1035,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         else if(!dquote && !squote && *p == ')') {
@@ -1160,33 +1043,28 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
 
         // 環境変数 $$
         else if(!squote && *p == '$' && *(p+1) == '$') {
             p+=2;
-            env = TRUE;
             user = FALSE;
         }
         // 環境変数 $
         else if(!squote && *p == '$') {
             p++;
-            env = TRUE;
             user = FALSE;
         }
 
         // 環境変数 @
         else if(!squote && *p == '@' && *(p+1) == '@') {
             p+=2;
-            env = TRUE;
             user = FALSE;
         }
         // 環境変数 @@
         else if(!squote && *p == '@') {
             p++;
-            env = TRUE;
             user = FALSE;
         }
         /// シングルクォート、ダブルクォート中 ///
@@ -1195,21 +1073,18 @@ char** readline_on_complete(const char* text, int start, int end)
         }
         else if(*p == '~') {
             p++;
-            env = FALSE;
             user = TRUE;
         }
         /// グロブ ///
         else if(*p == '*' || *p == '?' || *p =='[' && (*(p+1) != ' ' && *(p+1) != '\t' && *(p+1) == '\n')) 
         {
             p++;
-            env = FALSE;
             user = FALSE;
         }
 /*
         else if(*p == '-' && *(p+1) == '>') {
             p+=2;
             program = TRUE;
-            env = FALSE;
             user = FALSE;
         }
 */
@@ -1217,7 +1092,6 @@ char** readline_on_complete(const char* text, int start, int end)
             p++;
 
             program = FALSE;
-            env = FALSE;
             user = FALSE;
         }
         /// 単語の区切り /////////////////////////////////////////////////
@@ -1229,7 +1103,6 @@ char** readline_on_complete(const char* text, int start, int end)
             }
 
             if(program) program = FALSE;
-            env = FALSE;
             user = FALSE;
         }
         /// ブロック
@@ -1239,7 +1112,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         
@@ -1253,7 +1125,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         
@@ -1265,7 +1136,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         
@@ -1279,7 +1149,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         /// オアオア ///
@@ -1290,7 +1159,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         /// バックグラウンド ///
@@ -1301,7 +1169,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         /// セミコロン ///
@@ -1312,7 +1179,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         /// 改行 ///
@@ -1323,7 +1189,6 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         /// コメント ///
@@ -1343,11 +1208,9 @@ char** readline_on_complete(const char* text, int start, int end)
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
-            env = FALSE;
             user = FALSE;
         }
         else if(*p == '/') {
-            env = FALSE;
             user = FALSE;
             program = FALSE;
             p++;
@@ -1363,7 +1226,6 @@ char** readline_on_complete(const char* text, int start, int end)
         else if(*p == '(') {
             p++;
             program = TRUE;
-            env = FALSE;
             user = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
@@ -1378,10 +1240,6 @@ char** readline_on_complete(const char* text, int start, int end)
         rl_completion_append_character= 0;
         return rl_completion_matches(text, rl_username_completion_function);
     }
-    else if(env) {
-        rl_completion_append_character= ' ';
-        return rl_completion_matches(text, readline_env_completion);
-    }
     else if(program) {
         rl_completion_append_character= ' ';
         return rl_completion_matches(text, readline_program_completion);
@@ -1398,622 +1256,6 @@ char** readline_on_complete(const char* text, int start, int end)
 
     return NULL;
 }
-
-
-
-
-////////////////////////////////////////////////////////////
-// lftp, bashよりコピー
-////////////////////////////////////////////////////////////
-static bool shell_cmd;
-static bool quote_glob;
-static bool inhibit_tilde;
-
-/* mbschr.c - strchr(3) that handles multibyte characters. */
-
-/* Copyright (C) 2002 Free Software Foundation, Inc.
-
-   This file is part of GNU Bash, the Bourne Again SHell.
-
-   Bash is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 3 of the License, or
-   (at your option) any later version.
-
-   Bash is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Bash.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
-#include <config.h>
-
-#ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-#endif
-
-#undef mbschr
-
-/* In some locales, the non-first byte of some multibyte characters have
-   the same value as some ascii character.  Faced with these strings, a
-   legacy strchr() might return the wrong value. */
-
-char *
-#if defined (PROTOTYPES)
-mbschr (const char *s, int c)
-#else
-mbschr (s, c)
-     const char *s;
-     int c;
-#endif
-{
-#if HANDLE_MULTIBYTE
-  char *pos;
-  mbstate_t state;
-  size_t strlength, mblength;
-
-  /* The locale encodings with said weird property are BIG5, BIG5-HKSCS,
-     GBK, GB18030, SHIFT_JIS, and JOHAB.  They exhibit the problem only
-     when c >= 0x30.  We can therefore use the faster bytewise search if
-     c <= 0x30. */
-  if ((unsigned char)c >= '0' && MB_CUR_MAX > 1)
-    {
-      pos = (char *)s;
-      memset (&state, '\0', sizeof(mbstate_t));
-      strlength = strlen (s);
-
-      while (strlength > 0)
-	{
-	  mblength = mbrlen (pos, strlength, &state);
-	  if (mblength == (size_t)-2 || mblength == (size_t)-1 || mblength == (size_t)0)
-	    mblength = 1;
-
-	  if (mblength == 1 && c == (unsigned char)*pos)
-	    return pos;
-
-	  strlength -= mblength;
-	  pos += mblength;
-	}
-
-      return ((char *)NULL);
-    }
-  else
-#endif
-  return (strchr (s, c));
-}
-
-int
-file_exists (fn)
-     char *fn;
-{
-  struct stat sb;
-
-  return (stat (fn, &sb) == 0);
-}
-
-static char *
-quote_word_break_chars (text)
-     char *text;
-{
-  char *ret, *r, *s;
-  int l;
-
-  l = strlen (text);
-  ret = (char *)malloc ((2 * l) + 1);
-  for (s = text, r = ret; *s; s++)
-    {
-      /* Pass backslash-quoted characters through, including the backslash. */
-      if (*s == '\\')
-	{
-	  *r++ = '\\';
-	  *r++ = *++s;
-	  if (*s == '\0')
-	    break;
-	  continue;
-	}
-      //OK, we have an unquoted character.  Check its presence in rl_completer_word_break_characters. 
-
-      if (mbschr (rl_completer_word_break_characters, *s)) *r++ = '\\';
-      // XXX -- check for standalone tildes here and backslash-quote them
-      //if (s == text && *s == '~' && file_exists (text)) *r++ = '\\';
-      *r++ = *s;
-
-    }
-  *r = '\0';
-  return ret;
-}
-
-#define COMPLETE_DQUOTE  1
-#define COMPLETE_SQUOTE  2
-#define COMPLETE_BSQUOTE 3
-
-static int completion_quoting_style = COMPLETE_BSQUOTE;
-
-char *
-sh_single_quote (string)
-     char *string;
-{
-  register int c;
-  char *result, *r, *s;
-
-  result = (char *)malloc (3 + (4 * strlen (string)));
-  r = result;
-  *r++ = '\'';
-
-  for (s = string; s && (c = *s); s++)
-    {
-      *r++ = c;
-
-      if (c == '\'')
-	{
-	  *r++ = '\\';	/* insert escaped single quote */
-	  *r++ = '\'';
-	  *r++ = '\'';	/* start new quoted string */
-	}
-    }
-
-  *r++ = '\'';
-  *r = '\0';
-
-  return (result);
-}
-
-/* Quote STRING using double quotes.  Return a new string. */
-/*
-char *
-sh_double_quote (string)
-     char *string;
-{
-  register unsigned char c;
-  char *result, *r, *s;
-
-  result = (char *)malloc (3 + (2 * strlen (string)));
-  r = result;
-  *r++ = '"';
-
-  for (s = string; s && (c = *s); s++)
-    {
-      ///Backslash-newline disappears within double quotes, so don't add one. 
-      if ((sh_syntaxtab[c] & CBSDQUOTE) && c != '\n')
-	*r++ = '\\';
-      else if (c == CTLESC || c == CTLNUL)
-	*r++ = CTLESC;   /// could be '\\'? 
-
-      *r++ = c;
-    }
-
-  *r++ = '"';
-  *r = '\0';
-
-  return (result);
-}
-*/
-
-/* Turn S into a simple double-quoted string.  If FLAGS is non-zero, quote
-   double quote characters in S with backslashes. */
-char *
-sh_mkdoublequoted (s, slen, flags)
-     const char *s;
-     int slen, flags;
-{
-  char *r, *ret;
-  int rlen;
-
-  rlen = (flags == 0) ? slen + 3 : (2 * slen) + 1;
-  ret = r = (char *)malloc (rlen);
-  
-  *r++ = '"';
-  while (*s)
-    {
-      if (flags && *s == '"')
-	*r++ = '\\';
-      *r++ = *s++;
-    }
-  *r++ = '"';
-  *r = '\0';
-
-  return ret;
-}
-
-/* Remove backslashes that are quoting characters that are special between
-   double quotes.  Return a new string.  XXX - should this handle CTLESC
-   and CTLNUL? */
-/*
-char *
-sh_un_double_quote (string)
-     char *string;
-{
-  register int c, pass_next;
-  char *result, *r, *s;
-
-  r = result = (char *)malloc (strlen (string) + 1);
-
-  for (pass_next = 0, s = string; s && (c = *s); s++)
-    {
-      if (pass_next)
-	{
-	  *r++ = c;
-	  pass_next = 0;
-	  continue;
-	}
-      if (c == '\\' && (sh_syntaxtab[(unsigned char) s[1]] & CBSDQUOTE))
-	{
-	  pass_next = 1;
-	  continue;
-	}
-      *r++ = c;
-    }
-
-  *r = '\0';
-  return result;
-}
-*/
-
-/* Quote special characters in STRING using backslashes.  Return a new
-   string.  NOTE:  if the string is to be further expanded, we need a
-   way to protect the CTLESC and CTLNUL characters.  As I write this,
-   the current callers will never cause the string to be expanded without
-   going through the shell parser, which will protect the internal
-   quoting characters. */
-char *
-sh_backslash_quote (string)
-     char *string;
-{
-  int c;
-  char *result, *r, *s;
-
-  result = (char *)malloc (2 * strlen (string) + 1);
-
-  for (r = result, s = string; s && (c = *s); s++)
-    {
-      switch (c)
-	{
-	case ' ': case '\t': case '\n':		/* IFS white space */
-	case '\'': case '"': case '\\':		/* quoting chars */
-	case '|': case '&': case ';':		/* shell metacharacters */
-	case '(': case ')': case '<': case '>':
-	case '!': case '{': case '}':		/* reserved words */
-	case '*': case '[': case '?': case ']':	/* globbing chars */
-	case '^':
-	case '$': case '`':			/* expansion chars */
-	case ',':				/* brace expansion */
-	  *r++ = '\\';
-	  *r++ = c;
-	  break;
-#if 0
-	case '~':				/* tilde expansion */
-	  if (s == string || s[-1] == '=' || s[-1] == ':')
-	    *r++ = '\\';
-	  *r++ = c;
-	  break;
-
-	case CTLESC: case CTLNUL:		/* internal quoting characters */
-	  *r++ = CTLESC;			/* could be '\\'? */
-	  *r++ = c;
-	  break;
-#endif
-
-	case '#':				/* comment char */
-	  if (s == string)
-	    *r++ = '\\';
-	  /* FALLTHROUGH */
-	default:
-	  *r++ = c;
-	  break;
-	}
-    }
-
-  *r = '\0';
-  return (result);
-}
-
-/* Filename quoting for completion. */
-/* A function to strip quotes that are not protected by backquotes.  It
-   allows single quotes to appear within double quotes, and vice versa.
-   It should be smarter. */
-static char *
-bash_dequote_filename (const char *text, int quote_char)
-{
-  char *ret;
-  const char *p;
-  char *r;
-  int l, quoted;
-
-  l = strlen (text);
-  ret = (char*)malloc (l + 1);
-  for (quoted = quote_char, p = text, r = ret; p && *p; p++)
-    {
-      /* Allow backslash-quoted characters to pass through unscathed. */
-      if (*p == '\\')
-	{
-	  *r++ = *++p;
-	  if (*p == '\0')
-	    break;
-	  continue;
-	}
-      /* Close quote. */
-      if (quoted && *p == quoted)
-        {
-          quoted = 0;
-          continue;
-        }
-      /* Open quote. */
-      if (quoted == 0 && (*p == '\'' || *p == '"'))
-        {
-          quoted = *p;
-          continue;
-        }
-      *r++ = *p;
-    }
-  *r = '\0';
-  return ret;
-}
-
-
-
-
-static int skip_quoted(const char *s, int i, char q)
-{
-   while(s[i] && s[i]!=q)
-   {
-      if(s[i]=='\\' && s[i+1])
-	 i++;
-      i++;
-   }
-   if(s[i])
-      i++;
-   return i;
-}
-
-
-int lftp_char_is_quoted(const char *string,int eindex)
-{
-  int i, pass_next;
-
-  for (i = pass_next = 0; i <= eindex; i++)
-    {
-      if (pass_next)
-        {
-          pass_next = 0;
-          if (i >= eindex)
-            return 1;
-          continue;
-        }
-      else if (string[i] == '"' || string[i] == '\'')
-        {
-	  char quote = string[i];
-          i = skip_quoted (string, ++i, quote);
-          if (i > eindex)
-            return 1;
-          i--;  /* the skip functions increment past the closing quote. */
-        }
-      else if (string[i] == '\\')
-        {
-          pass_next = 1;
-          continue;
-        }
-    }
-  return (0);
-}
-
-
-
-
-
-
-
-
-
-
-/* Quote STRING using double quotes.  Return a new string. */
-static char *
-double_quote (char *string)
-{
-  register int c;
-  char *result, *r, *s;
-
-  result = (char *)malloc (3 + (2 * strlen (string)));
-  r = result;
-  *r++ = '"';
-
-  for (s = string; s && (c = *s); s++)
-    {
-      switch (c)
-        {
-	case '$':
-	case '`':
-	  if(!shell_cmd)
-	     goto def;
-	case '"':
-	case '\\':
-	  *r++ = '\\';
-	default: def:
-	  *r++ = c;
-	  break;
-        }
-    }
-
-  *r++ = '"';
-  *r = '\0';
-
-  return (result);
-}
-
-
-/* Return a new string which is the single-quoted version of STRING.
-   Used by alias and trap, among others. */
-static char *
-single_quote (char *string)
-{
-  register int c;
-  char *result, *r, *s;
-
-  result = (char *)malloc (3 + (4 * strlen (string)));
-  r = result;
-  *r++ = '\'';
-
-  for (s = string; s && (c = *s); s++)
-    {
-      *r++ = c;
-
-      if (c == '\'')
-	{
-	  *r++ = '\\';	/* insert escaped single quote */
-	  *r++ = '\'';
-	  *r++ = '\'';	/* start new quoted string */
-	}
-    }
-
-  *r++ = '\'';
-  *r = '\0';
-
-  return (result);
-}
-
-/* Quote special characters in STRING using backslashes.  Return a new
-   string. */
-static char *
-backslash_quote (char *string)
-{
-  int c;
-  char *result, *r, *s;
-
-  result = (char*)malloc (2 * strlen (string) + 1);
-
-  for (r = result, s = string; s && (c = *s); s++)
-    {
-      switch (c)
-	{
- 	case '(': case ')':
- 	case '{': case '}':			/* reserved words */
- 	case '^':
- 	case '$': case '`':			/* expansion chars */
-	  if(!shell_cmd)
-	    goto def;
- 	case '*': case '[': case '?': case ']':	/* globbing chars */
-	  if(!shell_cmd && !quote_glob)
-	    goto def;
-	case ' ': case '\t': case '\n':		/* IFS white space */
-	case '"': case '\'': case '\\':		/* quoting chars */
-	case '|': case '&': case ';':		/* shell metacharacters */
-	case '<': case '>': case '!':
-	  *r++ = '\\';
-	  *r++ = c;
-	  break;
-/*
-	case '~':				// tilde expansion 
-	  if (s == string && inhibit_tilde)
-	    *r++ = '.', *r++ = '/';
-	  goto def;
-*/
-	case '#':				/* comment char */
-	  if(!shell_cmd)
-	    goto def;
-	  if (s == string)
-	    *r++ = '\\';
-	  /* FALLTHROUGH */
-	default: def:
-	  *r++ = c;
-	  break;
-	}
-    }
-
-  *r = '\0';
-  return (result);
-}
-
-/* Quote a filename using double quotes, single quotes, or backslashes
-   depending on the value of completion_quoting_style.  If we're
-   completing using backslashes, we need to quote some additional
-   characters (those that readline treats as word breaks), so we call
-   quote_word_break_chars on the result. */
-static char *
-bash_quote_filename (char *s, int rtype, char *qcp)
-{
-  char *rtext, *mtext, *ret;
-  int rlen, cs;
-
-  rtext = (char *)NULL;
-
-  /* If RTYPE == MULT_MATCH, it means that there is
-     more than one match.  In this case, we do not add
-     the closing quote or attempt to perform tilde
-     expansion.  If RTYPE == SINGLE_MATCH, we try
-     to perform tilde expansion, because single and double
-     quotes inhibit tilde expansion by the shell. */
-
-  mtext = s;
-#if 0
-  if (mtext[0] == '~' && rtype == SINGLE_MATCH)
-    mtext = bash_tilde_expand (s);
-#endif
-
-  cs = completion_quoting_style;
-  /* Might need to modify the default completion style based on *qcp,
-     since it's set to any user-provided opening quote. */
-  if (*qcp == '"')
-    cs = COMPLETE_DQUOTE;
-  else if (*qcp == '\'')
-    cs = COMPLETE_SQUOTE;
-#if defined (BANG_HISTORY)
-  else if (*qcp == '\0' && history_expansion && cs == COMPLETE_DQUOTE &&
-	   history_expansion_inhibited == 0 && strchr (mtext, '!'))
-    cs = COMPLETE_BSQUOTE;
-
-  if (*qcp == '"' && history_expansion && cs == COMPLETE_DQUOTE &&
-        history_expansion_inhibited == 0 && strchr (mtext, '!'))
-    {
-      cs = COMPLETE_BSQUOTE;
-      *qcp = '\0';
-    }
-#endif
-
-  switch (cs)
-    {
-    case COMPLETE_DQUOTE:
-      rtext = double_quote (mtext);
-      break;
-    case COMPLETE_SQUOTE:
-      rtext = single_quote (mtext);
-      break;
-    case COMPLETE_BSQUOTE:
-      rtext = backslash_quote (mtext);
-      break;
-    }
-
-  if (mtext != s)
-    free (mtext);
-
-  /* We may need to quote additional characters: those that readline treats
-     as word breaks that are not quoted by backslash_quote. */
-  if (rtext && cs == COMPLETE_BSQUOTE)
-    {
-      mtext = quote_word_break_chars (rtext);
-      free (rtext);
-      rtext = mtext;
-    }
-
-  /* Leave the opening quote intact.  The readline completion code takes
-     care of avoiding doubled opening quotes. */
-  rlen = strlen (rtext);
-  ret = (char*)malloc (rlen + 1);
-  strcpy (ret, rtext);
-
-  /* If there are multiple matches, cut off the closing quote. */
-  if (rtype == MULT_MATCH && cs != COMPLETE_BSQUOTE)
-    ret[rlen - 1] = '\0';
-  free (rtext);
-  return ret;
-}
-
-
-
-
-
-
 // pathの最後は/をつける
 static BOOL readline_select_file_read(vector_obj* v, char* path)
 {
@@ -2077,9 +1319,6 @@ static void str_cut2(enum eKanjiCode code, char* mbs, int termsize, char* dest_m
             if(n < 0) {
                 xstrncpy(dest_mbs, "?????", dest_byte);
 
-                FREE(wcs);
-                FREE(tmp);
-
                 return;
             }
             else {
@@ -2098,9 +1337,6 @@ static void str_cut2(enum eKanjiCode code, char* mbs, int termsize, char* dest_m
         }
 
         wcstombs(dest_mbs, tmp, dest_byte);
-
-        FREE(wcs);
-        FREE(tmp);
     }
     else {
         int n;
@@ -2255,7 +1491,6 @@ static int readline_select_file(int count, int key)
                 else {
                     vector_erase(mark_files
                         , vector_index(mark_files, cursor_mfile));
-                    string_delete(cursor_mfile);
                 }
 
                 cursor++;
@@ -2263,10 +1498,6 @@ static int readline_select_file(int count, int key)
             else if(key == '\\') {
                 xstrncpy(current_dir, "/", PATH_MAX);
 
-                int i;
-                for(i=0; i<vector_size(v); i++) {
-                    sFile_delete(vector_item(v, i));
-                }
                 vector_clear(v);
 
                 readline_select_file_read(v, current_dir);
@@ -2346,10 +1577,6 @@ static int readline_select_file(int count, int key)
                             xstrncat(current_dir, "/", PATH_MAX);
                         }
 
-                        int i;
-                        for(i=0; i<vector_size(v); i++) {
-                            sFile_delete(vector_item(v, i));
-                        }
                         vector_clear(v);
 
                         readline_select_file_read(v, current_dir);
@@ -2362,10 +1589,6 @@ static int readline_select_file(int count, int key)
                 parentname(parent_path, PATH_MAX, current_dir);
                 xstrncpy(current_dir, parent_path, PATH_MAX);
 
-                int i;
-                for(i=0; i<vector_size(v); i++) {
-                    sFile_delete(vector_item(v, i));
-                }
                 vector_clear(v);
 
                 readline_select_file_read(v, current_dir);
@@ -2382,17 +1605,6 @@ static int readline_select_file(int count, int key)
         }
     }
 
-    int i;
-    for(i=0; i<vector_size(v); i++) {
-        sFile_delete(vector_item(v, i));
-    }
-    vector_delete(v);
-
-    for(i=0; i<vector_size(mark_files); i++) {
-        string_delete(vector_item(mark_files, i));
-    }
-    vector_delete(mark_files);
-
 //mclear();
 //mrefresh();
     mendwin();
@@ -2402,22 +1614,57 @@ static int readline_select_file(int count, int key)
     return 0;
 }
 
+static int skip_quoted(const char *s, int i, char q)
+{
+   while(s[i] && s[i]!=q)
+   {
+      if(s[i]=='\\' && s[i+1])
+	 i++;
+      i++;
+   }
+   if(s[i])
+      i++;
+   return i;
+}
 
+int lftp_char_is_quoted(const char *string,int eindex)
+{
+  int i, pass_next;
 
-
-
-
+  for (i = pass_next = 0; i <= eindex; i++)
+    {
+      if (pass_next)
+        {
+          pass_next = 0;
+          if (i >= eindex)
+            return 1;
+          continue;
+        }
+      else if (string[i] == '"' || string[i] == '\'')
+        {
+	  char quote = string[i];
+          i = skip_quoted (string, ++i, quote);
+          if (i > eindex)
+            return 1;
+          i--;  /* the skip functions increment past the closing quote. */
+        }
+      else if (string[i] == '\\')
+        {
+          pass_next = 1;
+          continue;
+        }
+    }
+  return (0);
+}
 
 void readline_init()
 {
     rl_attempted_completion_function = readline_on_complete;
     rl_completer_quote_characters = "\"'";
     rl_completer_word_break_characters = " \t\n\"'|{}!&;()<>=%/";
-    rl_filename_quote_characters = " \\\t\n\"|$*?[]!<>{}&;#()'%~";
+    rl_filename_quote_characters = " \\\t\n\"|$*?[]<>{}&;#()'%~";
     rl_completion_append_character= ' ';
     rl_char_is_quoted_p = (rl_linebuf_func_t*)lftp_char_is_quoted;
-    rl_filename_quoting_function = bash_quote_filename;
-    rl_filename_dequoting_function = (rl_dequote_func_t*)bash_dequote_filename;
 
 #if defined(HAVE_MIGEMO_H)
     migemo_init();
@@ -2430,15 +1677,6 @@ void readline_init()
 
 void readline_final()
 {
-    string_delete(gEditingDir);
-    int i;
-    if(files) {
-        int i;
-        for(i=0; i<vector_size(files); i++) {
-            string_delete(vector_item(files, i));
-        }
-        vector_delete(files);
-    }
 #if defined(HAVE_MIGEMO_H)
     migemo_final();
 #endif
