@@ -164,6 +164,9 @@ void saphire_kill_all_jobs();
     // 思われるのでsaphire_job_numで終わっていないジョブがあると
     // アプリケーションを終われないようにしとくほうがいいかもしれません。
 
+void saphire_init_stack_frame();
+    // スタックフレームの初期化
+
 extern vector_obj* gSaphireProgCompletions;               // 補完候補
 
 extern hash_obj* gGlobals;
