@@ -326,6 +326,12 @@ void saphire_set_local_var(char* name, char* value)
     }
 }
 
+void saphire_init_stack_frame()
+{
+    vector_clear(gStackFrame);
+    vector_add(gStackFrame, HASH_NEW(30));
+}
+
 void saphire_set_global_var(char* name, char* value)
 {
     string_obj* global = hash_item(gGlobals, name);
@@ -2106,6 +2112,7 @@ static void read_rc_file(BOOL run_user_runtimescript)
     if(access(rc_fname, R_OK) == 0) {
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
+        saphire_init_stack_frame();
         if(saphire_load(rc_fname
            , pipeout, pipein, STDERR_FILENO) < 0)
         {
@@ -2129,6 +2136,7 @@ static void read_rc_file(BOOL run_user_runtimescript)
             if(access(user_rc_fname, R_OK) == 0) {
                 sWFd* pipeout = sWFd_new(STDOUT_FILENO);
                 sRFd* pipein = sRFd_new(STDIN_FILENO);
+                saphire_init_stack_frame();
                 if(saphire_load(user_rc_fname
                     , pipeout, pipein, STDERR_FILENO) < 0)
                 {
@@ -2152,6 +2160,7 @@ static void read_rc_obj_file(BOOL run_user_runtimescript)
     if(access(rc_fname, R_OK) == 0) {
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
+        saphire_init_stack_frame();
         if(saphire_load_obj(rc_fname
            , pipeout, pipein, STDERR_FILENO, NULL) < 0)
         {
@@ -2175,6 +2184,7 @@ static void read_rc_obj_file(BOOL run_user_runtimescript)
             if(access(user_rc_fname, R_OK) == 0) {
                 sWFd* pipeout = sWFd_new(STDOUT_FILENO);
                 sRFd* pipein = sRFd_new(STDIN_FILENO);
+                saphire_init_stack_frame();
                 if(saphire_load_obj(user_rc_fname
                     , pipeout, pipein, STDERR_FILENO, NULL) < 0)
                 {
@@ -2213,7 +2223,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.0.8", 1);
+    setenv("SAPHIRE_VERSION", "3.0.9", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2250,7 +2260,6 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gStackTraceFName = VECTOR_NEW(30);
     gStackTraceLineNum = VECTOR_NEW(30);
 
-
 //    saphire_rehash();
 
     /// ランタイムスクリプト読み込み ///
@@ -2956,9 +2965,14 @@ BOOL sWFd_push_back(sWFd* self, char* str)
          
     }
 
-    if(self->mP - self->mBuffer > BUFSIZ) {
+    if(self->mFd == 1) {
         return sWFd_flash(self);
     }
+    else {
+        if(self->mP - self->mBuffer > BUFSIZ) {
+            return sWFd_flash(self);
+        }
+    }
 
     return TRUE;
 }
